import { Component, EventEmitter, Inject, Injectable, Input, NgModule, Output, ViewChild } from '@angular/core';
import { Headers, Http, HttpModule, RequestOptions } from '@angular/http';
import { Observable, Subscription } from 'rxjs/Rx';
import { BrowserModule } from '@angular/platform-browser';
import { InfiniteScrollModule } from 'ngx-infinite-scroll';
import { CommonModule } from '@angular/common';

// import { environment } from './../../environments/environment';
var SearchService = (function () {
    /**
     * @param {?} http
     * @param {?} environment
     */
    function SearchService(http$$1, environment) {
        this.http = http$$1;
        this.environment = environment;
        this.headers = new Headers({
            'accept-language': 'pt_BR',
            'Content-Type': 'application/json'
        });
    }
    /**
     * @param {?} searchValue
     * @param {?=} filter
     * @return {?}
     */
    SearchService.prototype.search = function (searchValue, filter) {
        if (filter === void 0) { filter = {}; }
        if (Object.keys(filter).length === 0 && filter.constructor === Object) {
            filter['city'] = 'all';
            filter['occupation'] = 'all';
            filter['field'] = 'all';
            filter['order'] = 'all';
            filter['page'] = 1;
        }
        var /** @type {?} */ options = new RequestOptions({ headers: this.headers }); // Create a request option
        // tslint:disable-next-line:max-line-length
        return this.http.get(this.environment.apiUrl + 'job/professional/filter/' + searchValue + '/' + filter['city'] + '/' + filter['occupation'] + '/' + filter['field'] + '/' + filter['order'] + '/' + filter['page'], options)
            .map(function (res) { return res.json(); })
            .catch(function (err) { return Observable.throw(err.json().error || 'Server error'); });
    };
    /**
     * @return {?}
     */
    SearchService.prototype.allCities = function () {
        var /** @type {?} */ options = new RequestOptions({ headers: this.headers }); // Create a request option
        return this.http.get(this.environment.apiUrl + 'all/address', options)
            .map(function (res) { return res.json(); })
            .catch(function (err) { return Observable.throw(err.json().error || 'Server error'); });
    };
    return SearchService;
}());
SearchService.decorators = [
    { type: Injectable },
];
/**
 * @nocollapse
 */
SearchService.ctorParameters = function () { return [
    { type: Http, },
    { type: undefined, decorators: [{ type: Inject, args: ['environments',] },] },
]; };

var FilterComponent = (function () {
    /**
     * @param {?} _searchService
     */
    function FilterComponent(_searchService) {
        this._searchService = _searchService;
        this.filterOutput = new EventEmitter();
        this.subscribeAllCities = new Subscription;
        this.filter = {};
        this.filter['city'] = 'all';
        this.filter['occupation'] = 'all';
        this.filter['field'] = 'none';
        this.filter['order'] = 'nameAsc';
        this.filter['page'] = 1;
    }
    /**
     * @return {?}
     */
    FilterComponent.prototype.ngOnInit = function () {
        this.cities();
        this.filterOutput.emit(this.filter);
    };
    /**
     * @return {?}
     */
    FilterComponent.prototype.cities = function () {
        var _this = this;
        this.subscribeAllCities = this._searchService.allCities().subscribe(function (data) {
            if (data.return) {
                _this.allCities = data.data;
            }
        });
    };
    /**
     * @param {?} city
     * @return {?}
     */
    FilterComponent.prototype.selectCity = function (city) {
        this.filter['city'] = city || 'all';
        this.filterOutput.emit(this.filter);
        this.listCities = null;
    };
    /**
     * @param {?} occupation
     * @return {?}
     */
    FilterComponent.prototype.searchOccupation = function (occupation) {
        this.filter['occupation'] = occupation || 'all';
        this.filterOutput.emit(this.filter);
    };
    /**
     * @param {?} value
     * @param {?=} maxResults
     * @return {?}
     */
    FilterComponent.prototype.citiesSearch = function (value, maxResults) {
        if (maxResults === void 0) { maxResults = 10; }
        if (value === '') {
            this.filter['city'] = 'all';
            this.listCities = [];
            this.filterOutput.emit(this.filter);
            return;
        }
        var /** @type {?} */ result = [];
        for (var /** @type {?} */ index = 0; index < this.allCities.length; index++) {
            var /** @type {?} */ re = new RegExp(value, 'i');
            if (re.test(this.allCities[index].city)) {
                result.push(this.allCities[index]);
                if (result.length === maxResults) {
                    break;
                }
            }
        }
        this.listCities = result;
    };
    /**
     * @return {?}
     */
    FilterComponent.prototype.ngOnDestroy = function () {
        this.subscribeAllCities.unsubscribe();
    };
    return FilterComponent;
}());
FilterComponent.decorators = [
    { type: Component, args: [{
                selector: 'app-filter',
                template: "<div class=\"filterBlock\"> <div class=\"cityBlock block\"> <label for=\"cityFilter\">Filtrar por Cidade</label> <div class=\"inputBlock\"> <input id=\"cityFilter\" type=\"text\" name=\"city\" #city (keyup)=\"citiesSearch(city.value)\" placeholder=\"Ex.: São Paulo\"> <button><i class=\"fa fa-search\" aria-hidden=\"true\" (click)=\"citiesSearch(city.value)\"></i></button> </div> <div class=\"resultsCities\" *ngIf=\"listCities\"> <ul class=\"citiesList\"> <ng-container *ngFor=\"let item of listCities\"> <li class=\"city\" (click)=\"selectCity(item.city); city.value = [item.city,item.uf,item.coutry].join(', '); \">{{ [item.city,item.uf,item.coutry].join(', ') }}</li> </ng-container> </ul> </div> </div> <div class=\"OccupationBlock  block\"> <label for=\"occupationFilter\">Filtrar por Profissão</label> <div class=\"inputBlock\"> <input id=\"occupationFilter\" type=\"text\" name=\"occupation\" #occupation (keyup)=\"searchOccupation(occupation.value)\" placeholder=\"Ex.: Analista\"> <button><i class=\"fa fa-search\" aria-hidden=\"true\" (click)=\"searchOccupation(occupation.value)\" ></i></button> </div> </div> </div>",
                styles: ["label { width: 100%; color: #575757; margin: 10px 0; text-align: left; } .block { border-bottom: 1px solid #999; padding: 30px; } .filterBlock { background-color: #fff; -webkit-box-shadow: 2px 2px 3px 1px rgba(0, 0, 0, 0.21); -moz-box-shadow: 2px 2px 3px 1px rgba(0, 0, 0, 0.21); -ms-box-shadow: 2px 2px 3px 1px rgba(0, 0, 0, 0.21); -o-box-shadow: 2px 2px 3px 1px rgba(0, 0, 0, 0.21); box-shadow: 2px 2px 3px 1px rgba(0, 0, 0, 0.21); } .inputBlock { position: relative; } .inputBlock input { width: 100%; padding: 15px; height: 40px; } .inputBlock button { position: absolute; right: 0; bottom: 0; top: 0; width: 40px; background-color: #007acc; border: none; outline: none; } .inputBlock button i { color: #fff; } .resultsCities { position: relative; } .resultsCities .citiesList { position: absolute; z-index: 1; width: 100%; background-color: #fff; list-style: none; -webkit-box-shadow: 2px 2px 3px 1px rgba(0, 0, 0, 0.21); -moz-box-shadow: 2px 2px 3px 1px rgba(0, 0, 0, 0.21); -ms-box-shadow: 2px 2px 3px 1px rgba(0, 0, 0, 0.21); -o-box-shadow: 2px 2px 3px 1px rgba(0, 0, 0, 0.21); box-shadow: 2px 2px 3px 1px rgba(0, 0, 0, 0.21); } .resultsCities .citiesList .city { padding: 10px 20px; text-align: left; cursor: pointer; } .resultsCities .citiesList .city:hover { font-weight: bold; } "]
            },] },
];
/**
 * @nocollapse
 */
FilterComponent.ctorParameters = function () { return [
    { type: SearchService, },
]; };
FilterComponent.propDecorators = {
    'filterOutput': [{ type: Output },],
};

var ResultComponent = (function () {
    /**
     * @param {?} environment
     */
    function ResultComponent(environment) {
        this.environment = environment;
        this.meUrl = environment.meUrl;
    }
    /**
     * @param {?} photosList
     * @return {?}
     */
    ResultComponent.prototype.moveLeft = function (photosList) {
        for (var /** @type {?} */ i = 0; i < 200; i++) {
            window.setTimeout(function () {
                photosList.scrollLeft -= 1;
            }, 150);
        }
    };
    /**
     * @param {?} photosList
     * @return {?}
     */
    ResultComponent.prototype.moveRight = function (photosList) {
        for (var /** @type {?} */ i = 0; i < 200; i++) {
            window.setTimeout(function () {
                photosList.scrollLeft += 1;
            }, 150);
        }
    };
    return ResultComponent;
}());
ResultComponent.decorators = [
    { type: Component, args: [{
                // tslint:disable-next-line:component-selector
                selector: 'search-result',
                template: "<div class=\"results\"> <div class=\"row\"> <ng-container *ngFor=\"let item of result; let id = index;\"> <div class=\"itemBlock col-lg-12 col-md-12 col-sm-12 col-xs-12\"> <div class=\"row\"> <div class=\"col-lg-2 col-md-2 col-sm-4 col-xs-12\"> <div class=\"imageBlock\"> <img src=\"{{  item.photoUrl }}\" alt=\"{{ item.name }} \"> <span class=\"status {{ item.statusChat }}\"> </span> </div> </div> <div class=\"col-lg-9 col-md-9 col-sm-8 col-xs-12\"> <div class=\"profileBlock\"> <h2 class=\"name\">{{ item.name }}</h2> <a href=\"{{ meUrl+item.username }}\" class=\"btn blue pull-right\" target=\"_blank\">Ver Perfil</a> <div class=\"viewsBlock\"> <span class=\"rating\"> <i class=\"fa fa-star{{item.ratingUser < 1?'-o':'' }}\" aria-hidden=\"true\"></i> <i class=\"fa fa-star{{item.ratingUser < 2?'-o':'' }}\" aria-hidden=\"true\"></i> <i class=\"fa fa-star{{item.ratingUser < 3?'-o':'' }}\" aria-hidden=\"true\"></i> <i class=\"fa fa-star{{item.ratingUser < 4?'-o':'' }}\" aria-hidden=\"true\"></i> <i class=\"fa fa-star{{item.ratingUser < 5?'-o':'' }}\" aria-hidden=\"true\"></i> </span> <span class=\"views\"> <i class=\"fa fa-eye\" aria-hidden=\"true\"></i> {{item.viewUser}} </span> <span class=\"views favorite\"> <i class=\"fa fa-heart-o\" aria-hidden=\"true\"></i> {{item.favoritesUser}} </span> </div> <div class=\"occupation\" *ngIf=\"item.occupation\"> <h3>[ {{item.occupation}} ]</h3> </div> <div class=\"info\" *ngIf=\"item.nrJobsDone\"> <span class=\"projects\"> Projetos Concluídos: <b>{{item.nrJobsDone}}</b> </span> <span class=\"startDate\"> Registrado desde: <b>{{ item.date | date:'d/M/y' }}</b> </span> </div> <div class=\"about\" *ngIf=\"item.bio\"> <h4>Sobre Mim</h4> <p>{{ (item.bio.length>200)? (item.bio | slice:0:200)+'...':(item.bio) }}</p> </div> <ul class=\"skills\" *ngIf=\"item.listAreaInterest\"> <ng-container *ngFor=\"let skill of item.listAreaInterest.split('¨|¨')\"> <li class=\"skillItem\">{{ skill.split('<|>')[1] }}</li> </ng-container> </ul> <div class=\"jobsList\" *ngIf=\"item.listJobs\"> <div class=\"blockTitle row\"> <div class=\"col-lg-8 col-md-8 col-sm-6 col-xs-12\"> <h4 class=\"title\">{{ item.listJobs.split('¨').length }} JOB{{ item.listJobs.split('¨').length > 1?'s':'' }}</h4> </div> <div class=\"col-lg-4 col-md-4 col-sm-6 col-xs-12\"> <span class=\"title\">Preço por hora</span> </div> </div> <div class=\"job row\"> <ng-container *ngFor=\"let job of item.listJobs.split('¨'); let idx = index \"> <a href=\"{{ meUrl+item.username+'/work/view/'+job.split(';')[0] }}\" *ngIf=\"idx < 5\" target=\"_blank\"> <div class=\" line col-lg-7 col-md-7 col-sm-6 col-xs-12\"> <h5 class=\"name\" title=\"{{ job.split(';')[1] }}\">{{ job.split(';')[1] }}</h5> </div> <div class=\"line col-lg-5 col-md-5 col-sm-6 col-xs-12\"> <div class=\"price\">{{ job.split(';')[2] }}</div> <div class=\"btnJob\"> <i class=\"fa fa-arrow-right\" aria-hidden=\"true\"></i> </div> </div> </a> <a class=\"btn blue pull-right\" href=\"{{ meUrl+item.username+'/work' }}\" *ngIf=\"idx === 5\">Ver Todos</a> </ng-container> </div> </div> <div class=\"photos\" *ngIf=\"item.listPhotos\"> <h4>Photos</h4> <div class=\"photosList\" #photoList> <ng-container *ngFor=\"let photo of item.listPhotos.split('¨|¨')\"> <a href=\"{{photo.split('<|>')[0]}}\" target=\"_blank\"> <img src=\"{{photo.split('<|>')[2]}}\"> </a> </ng-container> </div> <button class=\"left button hidden-sm hidden-xs\" (click)=\"moveLeft(photoList)\"><i class=\"fa fa-arrow-left\" aria-hidden=\"true\"></i></button> <button class=\"right button  hidden-sm hidden-xs\" (click)=\"moveRight(photoList)\"><i class=\"fa fa-arrow-right\" aria-hidden=\"true\"></i></button> </div> </div> </div> </div> </div> </ng-container> </div> </div>",
                styles: ["* { margin: 0; padding: 0; } .results { font-size: 16px; } .results .itemBlock { background-color: #fff; padding: 20px; margin-bottom: 30px; -webkit-box-shadow: 1px 1px 5px 2px rgba(0, 0, 0, 0.21); -moz-box-shadow: 1px 1px 5px 2px rgba(0, 0, 0, 0.21); -ms-box-shadow: 1px 1px 5px 2px rgba(0, 0, 0, 0.21); -o-box-shadow: 1px 1px 5px 2px rgba(0, 0, 0, 0.21); box-shadow: 1px 1px 5px 2px rgba(0, 0, 0, 0.21); } .results .itemBlock .imageBlock { margin: 15px auto; padding: 10px; width: 140px; height: 140px; text-align: center; } .results .itemBlock .imageBlock img { height: 115px; width: 115px; border: 5px solid #fff; -webkit-box-shadow: 2px 2px 3px 1px rgba(0, 0, 0, 0.21); -moz-box-shadow: 2px 2px 3px 1px rgba(0, 0, 0, 0.21); -ms-box-shadow: 2px 2px 3px 1px rgba(0, 0, 0, 0.21); -o-box-shadow: 2px 2px 3px 1px rgba(0, 0, 0, 0.21); box-shadow: 2px 2px 3px 1px rgba(0, 0, 0, 0.21); -webkit-border-radius: 50%; -moz-border-radius: 50%; -ms-border-radius: 50%; -o-border-radius: 50%; border-radius: 50%; } .results .itemBlock .imageBlock .status { position: absolute; bottom: 55px; left: 85px; } .results .itemBlock .profileBlock { text-align: left; padding: 10px; } .results .itemBlock .profileBlock h2 { font-size: 2.2rem; font-weight: 800; color: #555; margin-bottom: 5px; } .results .itemBlock .profileBlock .viewProfileButton { border: none; padding: 10px 20px; color: #fff; font-weight: bold; background-color: #007acc; text-decoration: none; margin-top: 15px; } .results .itemBlock .profileBlock .viewProfileButton:hover, .results .itemBlock .profileBlock .viewProfileButton:active { background-color: #0068AD; } .results .itemBlock .profileBlock .viewsBlock { margin-bottom: 15px; } .results .itemBlock .profileBlock .viewsBlock .rating { margin-right: 10px; } .results .itemBlock .profileBlock .viewsBlock .rating .fa-star { color: #f5d800; } .results .itemBlock .profileBlock .viewsBlock .rating .fa-star-o { color: #999; } .results .itemBlock .profileBlock .viewsBlock .views { margin-right: 10px; color: #999; } .results .itemBlock .profileBlock .viewsBlock .views i { color: #999; } .results .itemBlock .profileBlock .viewsBlock .favorite { margin-right: 10px; } .results .itemBlock .profileBlock .viewsBlock .favorite .fa-heart { color: #B80000; } .results .itemBlock .profileBlock .viewsBlock .favorite .fa-heart-o { color: #999; } .results .itemBlock .profileBlock .occupation { margin-bottom: 10px; } .results .itemBlock .profileBlock .occupation h3 { font-size: 1.5rem; color: #555; font-weight: 600; } .results .itemBlock .profileBlock .info { color: #555; margin-bottom: 20px; } .results .itemBlock .profileBlock .info .projects { margin-right: 15px; } .results .itemBlock .profileBlock .about { color: #999; font-size: 1.8rem; margin-bottom: 40px; } .results .itemBlock .profileBlock .about h4 { font-weight: 600; margin-bottom: 10px; } .results .itemBlock .profileBlock .about p { font-size: 1.6rem; } .results .itemBlock .profileBlock .skills { list-style: none; margin-bottom: 25px; width: 100%; height: 40px; overflow: hidden; } .results .itemBlock .profileBlock .skills .skillItem { display: inline-block; background-color: #00b1d9; padding: 4px 15px; margin: 5px 3px; -webkit-border-radius: 5px; -moz-border-radius: 5px; -ms-border-radius: 5px; -o-border-radius: 5px; border-radius: 5px; color: #fff; } .results .itemBlock .profileBlock .jobsList { margin-bottom: 20px; } .results .itemBlock .profileBlock .jobsList .blockTitle { padding: 10px 15px; border-bottom: 1px solid #999; } .results .itemBlock .profileBlock .jobsList .blockTitle .title { color: #999; font-size: 1.8rem; font-weight: 600; } .results .itemBlock .profileBlock .jobsList .job { font-weight: 600; font-size: 1.8rem; line-height: 1; } .results .itemBlock .profileBlock .jobsList .job .line { border-bottom: 1px solid #999; height: 50px; padding: 15px; } .results .itemBlock .profileBlock .jobsList .job .name { font-weight: 600; font-size: 1.8rem; color: #555; white-space: nowrap; overflow: hidden ; text-overflow: ellipsis; } .results .itemBlock .profileBlock .jobsList .job .price { color: #76A824; display: inline-block; } .results .itemBlock .profileBlock .jobsList .job .btnJob { width: 35px; height: 35px; display: inline-block; text-align: center; margin: -10px 15px; padding: 10px; float: right; -webkit-box-shadow: 2px 2px 3px 1px rgba(0, 0, 0, 0.21); -moz-box-shadow: 2px 2px 3px 1px rgba(0, 0, 0, 0.21); -ms-box-shadow: 2px 2px 3px 1px rgba(0, 0, 0, 0.21); -o-box-shadow: 2px 2px 3px 1px rgba(0, 0, 0, 0.21); box-shadow: 2px 2px 3px 1px rgba(0, 0, 0, 0.21); cursor: pointer; -webkit-border-radius: 50%; -moz-border-radius: 50%; -ms-border-radius: 50%; -o-border-radius: 50%; border-radius: 50%; } .results .itemBlock .profileBlock .jobsList .job .btnJob i { color: #999; } .results .itemBlock .profileBlock .photos { padding: 10px 15px; position: relative; } .results .itemBlock .profileBlock .photos h4 { font-weight: 600; font-size: 1.8rem; color: #555; padding-top: 10px; margin-bottom: 15px; } .results .itemBlock .profileBlock .photos .photosList { background-color: #fff; width: 100%; white-space: nowrap; overflow: auto; overflow: -moz-scrollbars-none; } .results .itemBlock .profileBlock .photos .photosList::-webkit-scrollbar { display: none; } .results .itemBlock .profileBlock .photos .photosList img { display: inline; margin: 0 auto; height: 100px; } .results .itemBlock .profileBlock .photos .button { position: absolute; bottom: 30%; background-color: #fff; border: none; outline: none; width: 35px; height: 35px; display: inline-block; text-align: center; margin: 0 15px; -webkit-box-shadow: 2px 2px 3px 1px rgba(0, 0, 0, 0.21); -moz-box-shadow: 2px 2px 3px 1px rgba(0, 0, 0, 0.21); -ms-box-shadow: 2px 2px 3px 1px rgba(0, 0, 0, 0.21); -o-box-shadow: 2px 2px 3px 1px rgba(0, 0, 0, 0.21); box-shadow: 2px 2px 3px 1px rgba(0, 0, 0, 0.21); cursor: pointer; -webkit-border-radius: 50%; -moz-border-radius: 50%; -ms-border-radius: 50%; -o-border-radius: 50%; border-radius: 50%; } .results .itemBlock .profileBlock .photos .button i { color: #999; } .results .itemBlock .profileBlock .photos .right { right: -40px; } .results .itemBlock .profileBlock .photos .left { left: -40px; } "]
            },] },
];
/**
 * @nocollapse
 */
ResultComponent.ctorParameters = function () { return [
    { type: undefined, decorators: [{ type: Inject, args: ['environments',] },] },
]; };
ResultComponent.propDecorators = {
    'result': [{ type: Input },],
};

var SearchInputComponent = (function () {
    /**
     * @param {?} _searchService
     */
    function SearchInputComponent(_searchService) {
        this._searchService = _searchService;
        this.listResult = new EventEmitter();
        this.subscribeSearch = new Subscription;
        this.subscribeUpdateSearch = new Subscription;
        this.searching = false;
        this.ordenation = false;
        this.oldFilter = null;
    }
    /**
     * @return {?}
     */
    SearchInputComponent.prototype.ngOnInit = function () {
        this.search();
    };
    /**
     * @param {?=} value
     * @return {?}
     */
    SearchInputComponent.prototype.search = function (value) {
        var _this = this;
        if (value === void 0) { value = 'all'; }
        if (this.filter['page']) {
            this.filter['page'] = 1;
        }
        this.searching = true;
        this.listResult.emit(null);
        this.subscribeSearch.unsubscribe();
        this.subscribeSearch = this._searchService.search(this.searchInput.nativeElement.value || 'all', this.filter).subscribe(function (data) {
            if (data.return) {
                _this.results = data.data;
                _this.listResult.emit(_this.results);
                _this.searching = false;
                _this.lenResult = data.totalRow;
            }
        });
    };
    /**
     * @return {?}
     */
    SearchInputComponent.prototype.updateSearch = function () {
        var _this = this;
        if (this.lenResult === this.results) {
            return;
        }
        this.filter['page']++;
        this.subscribeUpdateSearch = this._searchService.search(this.searchInput.nativeElement.value || 'all', this.filter).subscribe(function (data) {
            if (data.return) {
                if (_this.results) {
                    _this.results = _this.results.concat(data.data);
                }
                else {
                    _this.results = data.data;
                }
                _this.listResult.emit(_this.results);
            }
        });
    };
    /**
     * @param {?} order
     * @param {?} inputValue
     * @return {?}
     */
    SearchInputComponent.prototype.setOrder = function (order, inputValue) {
        if (this.ordenation && this.filter['order'] !== order) {
            this.filter['order'] = order;
            this.search();
        }
    };
    /**
     * @return {?}
     */
    SearchInputComponent.prototype.ngOnDestroy = function () {
        this.subscribeSearch.unsubscribe();
        this.subscribeUpdateSearch.unsubscribe();
    };
    return SearchInputComponent;
}());
SearchInputComponent.decorators = [
    { type: Component, args: [{
                selector: 'search-input',
                template: "<div class=\"inputBlock\" > <input type=\"text\" name=\"search\" #searchInput (keyup)=\"search()\"> <button type=\"submit\" (click)=\"search(searchInput.value)\"><i class=\"fa fa-search\" aria-hidden=\"true\" *ngIf=\"!searching\"></i><i class=\"fa fa-spinner fa-pulse fa-fw\" *ngIf=\"searching\"></i></button> </div> <div class=\"row\"> <div class=\"col-lg-7 col-md-7 col-sm-12 col-xs-12\"> <div class=\"msgResult\" *ngIf=\"!searching\"> <!-- <div class=\"title\">Resultado da Pesquisa</div> --> <div class=\"msg no-results\" *ngIf=\"lenResult==0\">Não foram encontrados resultados com o parâmetros informados!</div> <div class=\"msg\" *ngIf=\"lenResult==1\">Foi encontrado 1 resultado.</div> <div class=\"msg\" *ngIf=\"lenResult>1\">Foram encontrados {{lenResult}} resultados.</div> </div> </div> <div class=\"col-lg-5 col-md-5 col-sm-12 col-xs-12\"> <div class='sorterList'  (click)=\"ordenation = !ordenation\"> <div class=\"title\">Ordernar por:</div> <ul class=\"sort\" [ngClass]=\"ordenation ? 'box':''\"> <li class='item' [ngClass]=\"ordenation || filter['order'] === 'nameAsc' ? 'active':'inactive'\" (click)=\" setOrder('nameAsc',searchInput.value)\" >Nome [A - Z]<i class=\"fa fa-caret-down\" aria-hidden=\"true\"></i></li> <li class='item' [ngClass]=\"ordenation || filter['order'] === 'nameDesc' ? 'active':'inactive'\" (click)=\"  setOrder('nameDesc',searchInput.value)\" >Nome [Z - A]<i class=\"fa fa-caret-down\" aria-hidden=\"true\"></i></li> <li class='item' [ngClass]=\"ordenation || filter['order'] === 'procurDesc' ? 'active':'inactive'\" (click)=\" setOrder('procurDesc',searchInput.value)\" >Mais Populares<i class=\"fa fa-caret-down\" aria-hidden=\"true\"></i></li> <li class='item' [ngClass]=\"ordenation || filter['order'] === 'procurAsc' ? 'active':'inactive'\" (click)=\" setOrder('procurAsc',searchInput.value)\" >Menos Populares<i class=\"fa fa-caret-down\" aria-hidden=\"true\"></i></li> <li class='item' [ngClass]=\"ordenation || filter['order'] === 'precoDesc' ? 'active':'inactive'\" (click)=\" setOrder('precoDesc',searchInput.value)\" >Maior Salário<i class=\"fa fa-caret-down\" aria-hidden=\"true\"></i></li> <li class='item' [ngClass]=\"ordenation || filter['order'] === 'precoAsc' ? 'active':'inactive'\" (click)=\" setOrder('precoAsc',searchInput.value)\" >Menor Salário<i class=\"fa fa-caret-down\" aria-hidden=\"true\"></i></li> <li class='item' [ngClass]=\"ordenation || filter['order'] === 'statusDesc' ? 'active':'inactive'\" (click)=\" setOrder('statusDesc',searchInput.value)\" >Online<i class=\"fa fa-caret-down\" aria-hidden=\"true\"></i></li> </ul> </div> </div> </div>",
                styles: [".inputBlock { position: relative; max-width: 600px; margin: 0 auto; } .inputBlock input { width: 100%; height: 45px; padding: 14px 35px; font-size: 18px; color: #999; background-color: #fff; border: 1px solid #999; -webkit-box-shadow: 2px 2px 3px 1px rgba(0, 0, 0, 0.21); -moz-box-shadow: 2px 2px 3px 1px rgba(0, 0, 0, 0.21); -ms-box-shadow: 2px 2px 3px 1px rgba(0, 0, 0, 0.21); -o-box-shadow: 2px 2px 3px 1px rgba(0, 0, 0, 0.21); box-shadow: 2px 2px 3px 1px rgba(0, 0, 0, 0.21); outline: none; } .inputBlock button { position: absolute; top: 1px; bottom: 1px; right: 1px; width: 50px; border: none; outline: none; background-color: #007acc; } .inputBlock button i { color: #fff; } .msgResult { text-align: left; margin-top: 10px; font-size: 1.7rem; color: #575757; } .msgResult .title { font-weight: bold; } .msgResult .no-results { color: #ff6060; } .sorterList { width: 100%; text-align: left; position: relative; margin-top: 10px; color: #575757; cursor: pointer; } .sorterList .title { display: inline-block; font-weight: bold; padding: 5px 25px 10px; } .sorterList .sort { list-style: none; display: inline-block; padding: 0; height: 15px; } .sorterList .sort .item { color: #575757; padding: 5px 10px 10px 20px; margin-bottom: 5px; } .sorterList .sort .item .fa-caret-down { margin-left: 10px; } .sorterList .sort .item.inactive { display: none; } .sorterList .sort .item.active { display: block; } .sorterList .sort.box { position: absolute; background-color: #fff; -webkit-box-shadow: 2px 2px 3px 1px rgba(0, 0, 0, 0.21); -moz-box-shadow: 2px 2px 3px 1px rgba(0, 0, 0, 0.21); -ms-box-shadow: 2px 2px 3px 1px rgba(0, 0, 0, 0.21); -o-box-shadow: 2px 2px 3px 1px rgba(0, 0, 0, 0.21); box-shadow: 2px 2px 3px 1px rgba(0, 0, 0, 0.21); outline: none; z-index: 1; height: auto; } .sorterList .sort.box .item { display: block; } .sorterList .sort.box .item .fa-caret-down { display: none; } .sorterList .sort.box .item:hover { color: #007acc; } "]
            },] },
];
/**
 * @nocollapse
 */
SearchInputComponent.ctorParameters = function () { return [
    { type: SearchService, },
]; };
SearchInputComponent.propDecorators = {
    'listResult': [{ type: Output },],
    'filter': [{ type: Input },],
    'searchInput': [{ type: ViewChild, args: ['searchInput',] },],
};

var SearchComponent = (function () {
    function SearchComponent() {
        this.filter = {};
    }
    /**
     * @return {?}
     */
    SearchComponent.prototype.ngOnInit = function () {
    };
    /**
     * @param {?} event
     * @return {?}
     */
    SearchComponent.prototype.setResult = function (event) {
        this.returnSearch = event;
    };
    /**
     * @return {?}
     */
    SearchComponent.prototype.onScrollDown = function () { };
    /**
     * @param {?} event
     * @return {?}
     */
    SearchComponent.prototype.setFilter = function (event) {
        this.filter = event;
    };
    return SearchComponent;
}());
SearchComponent.decorators = [
    { type: Component, args: [{
                selector: 'app-search',
                template: "<div class=\"search\"> <div class=\"col-lg-9 col-lg-offset-3 col-md-9 col-md-offset-3 col-sm-12 col-xs-12\"> <search-input (listResult)=\"setResult($event)\" [filter]=\"filter\" #searchInput></search-input> </div> <div class=\"col-lg-3 col-md-3 hidden-sm hidden-xs\" *ngIf=\"true\"> <app-filter (filterOutput)=\"setFilter($event); searchInput.search()\"></app-filter> </div> <div class=\"col-lg-9 col-md-9  col-sm-12 col-xs-12\" *ngIf=\"true\"> <search-result [result]=\"returnSearch\" infiniteScroll [infiniteScrollDistance]=\"0\" [infiniteScrollThrottle]=\"5000\" (scrolled)=\"onScrollDown(); searchInput.updateSearch()\"></search-result> </div> </div>",
                styles: [".search { text-align: center; margin: 10px auto; } "]
            },] },
];
/**
 * @nocollapse
 */
SearchComponent.ctorParameters = function () { return []; };
SearchComponent.propDecorators = {
    'showResults': [{ type: Input },],
    'showFilters': [{ type: Input },],
};

var SearchGeneralModule = (function () {
    function SearchGeneralModule() {
    }
    /**
     * @param {?} environments
     * @return {?}
     */
    SearchGeneralModule.forRoot = function (environments) {
        return {
            ngModule: SearchGeneralModule,
            providers: [
                SearchService,
                { provide: 'environments', useValue: environments },
            ]
        };
    };
    return SearchGeneralModule;
}());
SearchGeneralModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    InfiniteScrollModule,
                    CommonModule,
                    HttpModule,
                    BrowserModule,
                ],
                declarations: [
                    SearchComponent,
                    SearchInputComponent,
                    ResultComponent,
                    FilterComponent
                ],
                exports: [
                    SearchComponent,
                    SearchInputComponent,
                    ResultComponent,
                    FilterComponent
                ]
            },] },
];
/**
 * @nocollapse
 */
SearchGeneralModule.ctorParameters = function () { return []; };

export { SearchGeneralModule, SearchComponent, SearchService, SearchInputComponent, ResultComponent, FilterComponent };
